﻿using System;
using System.Windows;
using System.Windows.Media;
using Infragistics.Documents.Excel;
using Infragistics.Documents.Excel.Charts;
namespace ExcelExportChart
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            Workbook workbook = new Workbook(WorkbookFormat.Excel2007);
            var sheet = workbook.Worksheets.Add("data");
            //titles
            sheet.Rows[0].Cells[0].Value = "Name";
            sheet.Rows[0].Cells[1].Value = "Height";
            sheet.Rows[0].Cells[2].Value = "Weight";
            //data
            sheet.Rows[1].Cells[0].Value = "Charles";
            sheet.Rows[1].Cells[1].Value = 170;
            sheet.Rows[1].Cells[2].Value = 80;
            sheet.Rows[2].Cells[0].Value = "Joan";
            sheet.Rows[2].Cells[1].Value = 160;
            sheet.Rows[2].Cells[2].Value = 50;
            sheet.Rows[3].Cells[0].Value = "Mike";
            sheet.Rows[3].Cells[1].Value = 180;
            sheet.Rows[3].Cells[2].Value = 82;
            sheet.Rows[4].Cells[0].Value = "Andrew";
            sheet.Rows[4].Cells[1].Value = 175;
            sheet.Rows[4].Cells[2].Value = 67;

            int xColumn = 1;
            int yColumn = 2;
            int firstDataRow = 1;
            int lastDataRow = 4;
            int labelColumn = 2;
            WorksheetRegion xRange = GetWorksheetRegion(sheet, firstDataRow, lastDataRow, xColumn, xColumn);
            WorksheetRegion labelRange = GetWorksheetRegion(sheet, firstDataRow, lastDataRow, labelColumn, labelColumn);
            WorksheetRegion vRange = GetWorksheetRegion(sheet, firstDataRow, lastDataRow, yColumn, yColumn);
            WorksheetChart chart = sheet.Shapes.AddChart(ChartType.XYScatter, sheet.Rows[1].Cells[4],
                new Point(0, 0), sheet.Rows[21].Cells[14], new Point(100, 100));

            chart.ChartTitle = new ChartTitle()
            {
                Text = new FormattedString("Weight vs Height chart")
            };
            chart.ChartArea.Border = new ChartBorder()
            {
                LineStyle = BorderLineStyle.Solid,
                WidthInPoints = 1
            };
            Axis xAxis = chart.AxisCollection[AxisType.Value, AxisGroup.Primary];
            xAxis.AxisTitle = new ChartTitle { Text = new FormattedString("Height (cm)") } ;
            Axis yAxis = chart.AxisCollection[AxisType.Value, AxisGroup.Secondary];
            yAxis.AxisTitle = new ChartTitle { Text = new FormattedString("Weight (kg)") };

            Series newSeries = chart.SeriesCollection.Add();
            newSeries.Name = new SeriesName("Name");
            newSeries.Line = new ChartLine()
            {
                Fill = new ChartEmptyFill(),
                LineStyle = LineStyle.None,
                WidthInPoints = 0
            };
            newSeries.MarkerFill = new ChartSolidFill(new WorkbookColorInfo(Colors.DarkBlue));
            newSeries.MarkerBorder = new ChartBorder() { Fill = new ChartSolidFill(new WorkbookColorInfo(Colors.DarkBlue)) };
            newSeries.MarkerSize = 4;
            newSeries.MarkerStyle = MarkerStyle.Circle;

            newSeries.Values = new SeriesValues(sheet, vRange.ToString(), CellReferenceMode.A1);
            newSeries.XValues = new XValues(sheet, xRange.ToString(), CellReferenceMode.A1);
            newSeries.DataLabels.SetDataLabelsRange(labelRange.ToString(), CellReferenceMode.A1);
            newSeries.ShowDataLabels = true;
            try
            {
                workbook.Save("excelFile.xlsx");
            }
            catch (Exception e)
            {
                MessageBox.Show(e.ToString());
            }

            InitializeComponent();
            Close();
        }

        WorksheetRegion GetWorksheetRegion(Worksheet workSheet, int rowInit, int rowEnd, int colInit, int colEnd)
        {
            WorksheetCell rangeInit = workSheet.Rows[rowInit].Cells[colInit];
            WorksheetCell rangeEnd = workSheet.Rows[rowEnd].Cells[colEnd];

            string stringRange = rangeInit.ToString(CellReferenceMode.A1, false) + ":" +
                    rangeEnd.ToString(CellReferenceMode.A1, false);

            WorksheetRegion range = workSheet.GetRegion(stringRange);
            return range;
        }
    }
}
